/******************************************************************
 * Copyright and Permission Notice                                *
 *                                                                *
 * Permission is granted to copy, use, modify, and merge this     *
 * software into your applications and to permit others to do any *
 * of the foregoing for non-commercial use only. You must include *
 * this permission and copyright notice in all copies and         *
 * modified versions of this software, and include attribution    *
 * to Taligent in all splash screens included in any application  *
 * using this software. You must require others to whom you       *
 * distribute this software to do likewise.                       *
 *                                                                *
 * To obtain an unrestricted commercial license to the software   *
 * source and/or binaries, please contact Taligent at             *
 * widgets@taligent.com                                           *
 *                                                                *
 * THE SOFTWARE IS PROVIDED IN ITS 'AS IS' CONDITION FOR          *
 * NON-COMMERCIAL USE ONLY. TALIGENT DISCLAIMS ANY LIABILITY OF   *
 * ANY KIND FOR DAMAGES WHATSOEVER RESULTING FROM THE USE OF      *
 * THIS SOFTWARE.                                                 *
 *                                                                *
 * (C) Copyright Taligent, Inc. 1997-All Rights Reserved.         *
 * (C) Copyright IBM Corporation 1997                             *
 ******************************************************************/

import java.awt.*;
import java.awt.event.*;

import COM.taligent.widget.*;

/**
 * A sample applet used as a tutorial on how to use the
 * MaskedTextField.
 *
 * @author  Andy Clark, Taligent Inc.
 * @version 1.0
 */
public class SampleMaskedTextField
    extends java.applet.Applet
    implements ActionListener
    {
    //
    // Constants
    //
    private static final MaskCharacter MASKCHARS[] = {
        MaskCharacter.UPPERCASE, // only uppercase letters
        MaskCharacter.LOWERCASE, // only lowercase letters
        MaskCharacter.DIGITS,    // only numbers

        new MaskCharacter('>', "a-zA-Z", "A-ZA-Z"), // to uppercase
        new MaskCharacter('<', "a-zA-Z", "a-za-z"), // to lowercase

        new MaskCharacter('.', "\u0000-\uFFFF") // any Unicode char
        };

    //
    // GUI Components
    //
    private MaskedTextField mask;
    private TextField       text;

    // setup applet
    public void init() {

        setBackground(Color.lightGray);
        setLayout(new GridLayout(2, 1, 2, 2));

        // create and init masked text field
        mask = new MaskedTextField();
        mask.setMaskCharacters(MASKCHARS);
        mask.setMask("\\A: AA, \\a: aa, \\#: ##, \\>: >>, \\<: <<, \\.: ..");

        // create and init text field
        text = new TextField();
        text.setBackground(Color.lightGray);
        text.setEditable(false);

        // set display attributes
        Font font = new Font("Courier", Font.PLAIN, 12);
        mask.setFont(font);
        text.setFont(font);

        // add components to panel
        add(mask);
        add(text);

        // add listeners
        mask.addActionListener(this);

        setSize(300, 55);
        setVisible(true);
        }

    // action performed
    public void actionPerformed(ActionEvent evt) {
        Object source = evt.getSource();

        if (source == mask) {
            text.setText(mask.getText());
            }
        }
    }